@@ -36,11 +36,20 @@ public class SessionCheckerServiceImpl extends RemoteServiceServlet implements
 
 	@Override
 	public SessionInfoBean checkSession() {
-		SessionManager manager = SessionManager.getInstance();
+		SessionManager manager = null;
+		try { 
+			manager = SessionManager.getInstance();
+		}
+		catch (NullPointerException e) {
+			_log.error("SessionManager#getInstance null");
+			return new SessionInfoBean("",""); //tells session expired
+		}
 		if (manager == null) {
 			_log.warn("Liferay Portal Detected but session Expired");
 			return new SessionInfoBean("",""); //tells session expired
 		}
+		
+		
 		ASLSession session = null;
 		try { 
 			session = getASLSession();
